Changes
~~~~~~~

.. Future (?)
.. ----------
.. -

0.0.1 (2019-04-18)
------------------
- Carve out functionality from dockery-odoo-scaffold hack
- init: helper to initialize an odoo project
- repo: toolset to manage your own odoo-dev / patches
